@@ -12,7 +12,7 @@
 # A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.  BOOTLOADER SHALL NOT BE
 # LIABLE FOR ANY LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF
 # USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
-
+import os
 from pathlib import Path
 import re
 
@@ -152,7 +152,7 @@ def update_ios_version(
     for i in range(len(lines)):
         regex_match = REGEX_PROPERTY_ADDITIONAL_PLIST_DATA.match(lines[i].strip())
         if regex_match:
-            lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_ADDITIONAL_PLIST_DATA}={version.plist_data}'
+            lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_ADDITIONAL_PLIST_DATA}={version.plist_data}{os.linesep}'
             is_additional_plist_data_property_defined = True
             break
 
@@ -197,7 +197,7 @@ def update_project_version(
     for i in range(len(lines)):
         regex_match = REGEX_PROPERTY_PROJECT_VERSION.match(lines[i].strip())
         if regex_match:
-            lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}={version}'
+            lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}={version}{os.linesep}'
             is_project_version_property_defined = True
             break
 
